// slush/default/task.js
'use strict';

// require plugins
var gulp     = require('gulp'),
    install  = require('gulp-install'),
    conflict = require('gulp-conflict'),
    template = require('gulp-template'),
    rename   = require('gulp-rename'),
    _        = require('underscore.string'),
    inquirer = require('inquirer'),
    filter   = require('gulp-filter'),
    gutil    = require('gulp-util');

// require questions
var questions = require('./questions');

// start default task
module.exports = function(options) {

    gulp.task('default', function(done) {

        // show welcome message
        gutil.log(
            '\n\n           . ----------------------------- .      \n'+
            '           |            '+gutil.colors.magenta('_--╱--_')+'            |     \n'+
            '           |           '+gutil.colors.magenta('| Slush |')+'           |     \n'+
            '           |            '+gutil.colors.magenta('|  ◼  |')+'            |     \n'+
            '           |             '+gutil.colors.magenta('|___|')+'             |     \n'+
            '           |                               |     \n'+
            '           |    ' + gutil.colors.yellow('Welcome to Web-Kickstart')+'       |      \n'+
            '           . ----------------------------- .        \n'

        );

        // start asking & start task
        inquirer.prompt(questions,
            function(answers) {

                if (!answers.moveon) {
                    return done();
                }

                answers.projectNameSlug = _.slugify(answers.projectName);
                var d = new Date();
                answers.year = d.getFullYear();

                var files = [options.templatesDir + '/**'];
                if (answers.cssFramework === 'foundation-sites') {
                    files.push(
                        '!' + options.templatesDir + '/app/templates/includes/bootstrap.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/mdl.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/materialize.nunjucks'
                    );
                } else if (answers.cssFramework === 'bootstrap-v4.0.0-alpha') {
                    files.push(
                        '!' + options.templatesDir + '/app/templates/includes/foundation.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/mdl.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/materialize.nunjucks'
                    );
                } else if (answers.cssFramework === 'mdl') {
                    files.push(
                        '!' + options.templatesDir + '/app/templates/includes/foundation.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/bootstrap.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/materialize.nunjucks'
                    );
                } else if (answers.cssFramework === 'materialize') {
                    files.push(
                        '!' + options.templatesDir + '/app/templates/includes/foundation.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/bootstrap.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/mdl.nunjucks'
                    );
                } else {
                    files.push(
                        '!' + options.templatesDir + '/app/templates/includes/bootstrap.scss',
                        '!' + options.templatesDir + '/app/templates/includes/foundation.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/mdl.nunjucks',
                        '!' + options.templatesDir + '/app/templates/includes/materialize.nunjucks'
                    );
                }

                // avoid pass images and fonts through gulp-template
                var filterImagesAndFonts = filter(['**/**', '!app/fonts/**', '!app/images/**'], {
                    restore: true
                });

                gulp.src(files)
                    .pipe(filterImagesAndFonts) // remove the images and fonts
                    .pipe(template(answers))
                    .pipe(filterImagesAndFonts.restore) // restore the images and fonts
                    .pipe(rename(function(file) {
                        if (file.basename[0] === '@') {
                            file.basename = '.' + file.basename.slice(1);
                        }
                    }))
                    .pipe(conflict('./'))
                    .pipe(gulp.dest('./'))
                    .pipe(install())
                    .on('end', function() {
                        done();
                    });

            }
        );

    });

};