// gulp/config.js
'use strict';

// require gulp-util & paths
var gutil    = require('gulp-util'),
    path     = require('./paths.js'),

    // require for imagemin options
    pngquant = require('imagemin-pngquant');

// project local url
var url = 'gulp.dev';

// define options
module.exports = {

    // tasks names
    task: {
      browserSync: 'serve',
      fonts      : 'fonts',
      scss       : 'scss',
      scripts    : 'js',
      images     : 'images',
      bower      : 'bower',
      nunjucks   : 'nunjucks',
      clean      : 'clean',
      build      : 'build'
    },

    // serve task browser-sync options
    serve: {
        dev: {
            ui: {
              port: 3500
            },
            server: {
              baseDir: [path.to.dist.dev, path.to.src],
              routes: {
                "/bower_components": "bower_components"
              }
            },
            // don't notify on connect
            notify: false,
            // browser that is opened
            browser: 'google chrome'
            // for more options: http://www.browsersync.io/docs/options
        },
        prod: {
          server: {
              baseDir: path.to.dist.prod
            },
            // don't notify on connect
            notify: false,
            // browser that is opened
            browser: 'google chrome'
        }
    },

    // wiredep options
    wiredep: {
        dev: {
            ignorePath: '../../app/'
        }
    },

    rename: {
      dev: {
        js: 'scripts.js'
      }
    },

    // nunjucks task options
    nunjucks: {
        // inject task options
        inject: {
           options: {
                relative: true
           } 
        }
    },

    // sass task options
    scss: {
        // main options
        options: {
            outputStyle: 'expanded'
            // more options
            // https://github.com/sass/node-sass#usage-1
        },
    },

    // html task options
    html: {
        htmlminOptions: {
            removeComments: true,
            collapseWhitespace: true,
            preserveLineBreaks: true,
            removeScriptTypeAttributes: true,
            removeStyleLinkTypeAttributes: true,
            collapseBooleanAttributes: true
            // more options : https://github.com/kangax/html-minifier
        },
        // build:html:inject options
        inject: {
            options: {
                relative: true,
                // more options : https://github.com/klei/gulp-inject#api
            }
        }
    },

    // css task options
    css: {
        // uncss options
        uncssOptions: {
            html: [path.to.dist.dev + '/**/*.html'],
            ignore: [
                /.is-/,
                /.has-/
            ]
            // more options
            // https://github.com/giakki/uncss#within-nodejs
        },
        cssnanoOptions: {
            autoprefixer: false,
            discardComments: {
                removeAll: true
            },
            zindex: false,
            mergeIndents: false
        }
    },

    // images task options
    images: {
        // imagemin options
        imageminOptions: {
            optimizationLevel: 5,
            progressive: true,
            interlaced: true,
            use: [pngquant()] // imagemin-pngquant
        },
        // favicons options
        faviconsOptions: {
            appName: 'Gulpfile Setup',
            appDescription: 'Gulpfile setup',
            developerName: 'lihoagency',
            developerURL: 'http://lighthouseagency.be/',
            background: '#020307',
            path: 'images/favicons/',
            url: '/',
            display: 'standalone',
            orientation: 'portrait',
            version: 1.0,
            logging: false,
            online: false,
            html: path.to.nunjucks.config + 'includes/favicons.nunjucks',
            replace: true,
            icons: {
                android: true, // create Android homescreen icon
                appleIcon: true, // create Apple touch icons
                appleStartup: false, // create Apple startup images
                coast: false, // create Opera Coast icon
                favicons: true, // create regular favicons
                firefox: false, // create Firefox OS icons
                opengraph: true, // create Facebook OpenGraph image
                twitter: true, // create Twitter Summary Card image
                windows: false, // create Windows 8 tile icons
                yandex: false // create Yandex browser icon
            }
            // options from here : https://github.com/haydenbleasel/favicons#nodejs
        }
    },

    <% if (slack) { %>

    slack: {
      build: {
        url: '<%= webhook %>', //'https://hooks.slack.com/services/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',
        icon_url: "https://slack.com/img/icons/app-57.png",
        icon_emoji: ':octocat:',
        user: 'gulp-bot',

        messaging: {
          "title": "New build process completed for <%= projectName %>",
          "fallback": "New build process completed",
          "text": "<%= projectDescription %>",
          "fields": [
            {
              "title": "Project",
              "value": "<%= projectName %> v<%= projectVersion %>",
              "short": "true"
            },
            {
              "title": "user",
              "value": "<%= projectUser %>",
              "short": "true"
            }
          ],
          "color": "#7CD197",
          "mrkdwn_in": ["text", "pretext", "fields"]
        }
      }
    },

    <% } %>

    // error handler
    error: function(error) {
        // output an error message
        gutil.log(
            gutil.colors.red(
                '\n\------------------------------\n\Error in plugin (' + gutil.colors.green(error.plugin) + '):\n\ ' + gutil.colors.blue(error.message) + '------------------------------'
            )
        );
        // emit the end event, to properly end the task
        this.emit('end');
    }
    
};