// gulp/tasks/build/images.js
'use strict';

// ----------------------------------
// available tasks: 
//    'gulp build:images'   : main image task
//    'gulp build:minify'   : minify images
//    'gulp build:webp'     : convert images to webp if possible
// ----------------------------------
// plugins:
//      gulp-plumber      : $.plumber
//      gulp-webp         : $.webp
//      gulp-imagemin     : $.imagemin
//      gulp-changed      : $.changed
//      gulp-newer        : $.newer
//      imagemin-pngquant : $.pngquant
// ----------------------------------
// config:
//     config.task.build : task name
// ----------------------------------

module.exports = function(gulp, $, path, config) {

    // minify images task
    gulp.task(config.task.images + ':minify', 'minify images', function() {

        return gulp.src(path.to.images.src)
            // prevent breaking errors
            .pipe($.plumber({
                errorHandler: config.error
            }))
            // only pass through changed files
            .pipe($.changed(path.to.images.dist.prod + '/**/*'))
            // only pass through newer source files
            .pipe($.newer(path.to.images.dist.prod + '/**/*'))
            // minify images
            .pipe($.imagemin(
                config.images.imageminOptions // options
            ))
            .pipe(gulp.dest(path.to.images.dist.prod));

    });

    gulp.task(config.task.images + ':webp', 'convert to webp', function() {

      return gulp.src(
        [
          path.to.images.dist.prod + '/**/*.+(png|jpg|jpeg)', 
          '!'+ path.to.images.dist.favicons + '{,/**}'
        ]
      )
        //prevent breaking errors
        .pipe($.plumber({
          errorHandler: config.error
        }))
        .pipe($.webp())
        .pipe(gulp.dest(path.to.images.dist.prod + '/webp'));
    });

      // main nunjucks task
  gulp.task(config.task.build + ':images', 'main images task', function(cb) {
    $.runSequence(
      [
        config.task.images + ':minify',
        config.task.images + ':webp'
      ],
      cb
    )
  });

};