// gulp/tasks/default/sass.js
'use strict';

// ----------------------------------
// available tasks: 
//    'gulp sass'              : main sass task
//    'gulp sass:compile'      : compile scss to css
// ---------------------------------- 
// plugins:
//     gulp-sass        : $.sass
//     browser-sync     : $.browserSync
//     gulp-changed     : $.changed
//     gulp-newer       : $.newer
//     gulp-cached      : $.cached
//     gulp-sourcemaps  : $.sourcemaps
//     gulp-autoprefixer: $.autoprefixer
//     lazypipe         : $.lazypipe
//     gulp-plumber     : $.plumber
// ----------------------------------
// config:
//     config.task.scss : task name
// ----------------------------------

module.exports = function(gulp, $, path, config) {
  var wiredep = $.wiredep.stream;

  // split commonly used stream chains [ changed - newer - cached ]
  var cacheFiles = $.lazypipe()
    // only pass through changed files
    .pipe($.changed, path.to.scss.dist.dev + '/**/*.css')
    // only pass through newer files
    .pipe($.newer, path.to.scss.dist.dev + '/**/*.css')
    // start cache
    .pipe($.cached, 'scss')

  gulp.task(config.task.scss + ':wiredep', 'insert bower components into scss main file', function() {
    return gulp.src(path.to.scss.src) 
      .pipe($.plumber({
        errorHandler: config.error
      }))
      .pipe(wiredep())
      .pipe(gulp.dest(path.to.scss.main))
  })

  // compile scss
  gulp.task(config.task.scss + ':compile', 'compile scss to css', function() {
    return gulp.src(path.to.scss.src) 
      .pipe($.plumber({
        errorHandler: config.error
      }))
      // only pass through changed, newer & not cached files
      .pipe(cacheFiles())
      // add bower dependencies
      .pipe(wiredep())
      // initialize sourcemaps
      .pipe($.sourcemaps.init({debug: true}))
      // start compiling
      .pipe($.sass(
        config.scss.options
      ))
      // prefixing css
      .pipe($.autoprefixer())
      // writing sourcemaps
      .pipe($.sourcemaps.write('./_maps'))
      .pipe(gulp.dest(path.to.scss.dist.dev))
      .pipe($.browserSync.reload({
        stream: true
      }));
  });

  // main scss task
  gulp.task(config.task.scss, 'main scss task', function(cb) {
    $.runSequence(
      config.task.scss + ':wiredep',
      config.task.scss + ':compile',
      cb
    )
  });

};